---
name: Bug report
about: Report an error that should be fixed
title: "<Enter short description of observed bug>"
labels: bug
assignees: ''

---

**Description of the bug**
Provide a clear and concise description of the bug. About 1-3 lines is enough.

**How To Reproduce**
Let us know how to reproduce the bug. This should be a [minimal, reproducible example](https://stackoverflow.com/help/minimal-reproducible-example); if you cannot create a standalone example, provide a code sample where the error occurs (function, class or method) plus some context on when the error occurs.

**Expected behavior**
A clear and concise description of what you expect to happen instead.
